@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2019-06-25'; # DATE
+our $VERSION = '0.470'; # VERSION
 
 use 5.010001;
 use strict;
@@ -151,6 +151,11 @@ _
             schema  => 'hash*',
             req     => 1,
         },
+        summaries => {
+            summary => 'Summary text for each option spec '.
+                '(key in `getopt_spec`)',
+            schema => 'hash*',
+        },
         completion => {
             summary     =>
                 'Completion routine to complete option value/argument',
@@ -287,6 +292,7 @@ sub complete_cli_arg {
     my @words = @{ $args{words} };
     defined(my $cword = $args{cword}) or die "Please specify cword";
     my $gospec = $args{getopt_spec} or die "Please specify getopt_spec";
+    my $summaries = $args{summaries};
     my $comp = $args{completion};
     my $extras = $args{extras} // {};
     my $bundling = $args{bundling} // 1;
@@ -537,11 +543,12 @@ sub complete_cli_arg {
         #say "D:completing option names";
         my $opt = $exp->{optname};
         my @o;
-        for (@optnames) {
+        my @osumms;
+        for my $optname (@optnames) {
             my $repeatable = 0;
-            next if $exp->{short_only} && /\A--/;
-            if ($seen_opts{$_}) {
-                my $opthash = $opts{$_};
+            next if $exp->{short_only} && $optname =~ /\A--/;
+            if ($seen_opts{$optname}) {
+                my $opthash = $opts{$optname};
                 my $ospecval = $gospec->{$opthash->{ospec}};
                 my $parsed = $opthash->{parsed};
                 if (ref($ospecval) eq 'ARRAY') {
@@ -552,22 +559,25 @@ sub complete_cli_arg {
             }
             # skip options that have been specified and not repeatable
             #use DD; dd {'$_'=>$_, seen=>$seen_opts{$_}, repeatable=>$repeatable, opt=>$opt};
-            next if $seen_opts{$_} && !$repeatable && (
+            next if $seen_opts{$optname} && !$repeatable && (
                 # long option has been specified
-                (!$opt || $opt ne $_) ||
+                (!$opt || $opt ne $optname) ||
                      # short option (in a bundle) has been specified
                     (defined($exp->{prefix}) &&
                          index($exp->{prefix}, substr($opt, 1, 1)) >= 0));
             if (defined $exp->{prefix}) {
-                my $o = $_; $o =~ s/\A-//;
+                my $o = $optname; $o =~ s/\A-//;
                 push @o, "$exp->{prefix}$o";
             } else {
-                push @o, $_;
+                push @o, $optname;
             }
+            push @osumms, $summaries->{ $opts{$optname}{ospec} } if $summaries;
         }
         #use DD; dd \@o;
         my $compres = Complete::Util::complete_array_elem(
-            array => \@o, word => $word);
+            array => \@o, word => $word,
+            (summaries => \@osumms) x !!$summaries,
+        );
         #$log->tracef('[comp][compgl] adding result from option names, '.
         #                 'matching options=%s', $compres);
         push @answers, $compres;
@@ -582,7 +592,7 @@ sub complete_cli_arg {
         last unless exists($exp->{optval});
         #say "D:completing option value";
         my $opt = $exp->{optval};
-        my $opthash = $opts{$opt} if $opt;
+        my $opthash; $opthash = $opts{$opt} if $opt;
         my %compargs = (
             %$extras,
             type=>'optval', words=>\@words, cword=>$args{cword},
@@ -620,7 +630,7 @@ sub complete_cli_arg {
         );
         #$log->tracef('[comp][compgl] invoking \'completion\' routine '.
         #                 'to complete argument');
-        my $compres = $comp->(%compargs) if $comp;
+        my $compres; $compres = $comp->(%compargs) if $comp;
         if (!defined $compres) {
             $compres = _default_completion(%compargs);
             #$log->tracef('[comp][compgl] adding result from default '.
@@ -652,7 +662,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.46 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2017-01-13.
+This document describes version 0.470 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2019-06-25.
 
 =head1 SYNOPSIS
 
@@ -663,7 +673,11 @@ See L<Getopt::Long::Complete> for an easy way to use this module.
 =head1 FUNCTIONS
 
 
-=head2 complete_cli_arg(%args) -> hash|array
+=head2 complete_cli_arg
+
+Usage:
+
+ complete_cli_arg(%args) -> hash|array
 
 Complete command-line argument using Getopt::Long specification.
 
@@ -783,6 +797,10 @@ described in the function description will not be overwritten by this.
 
 Getopt::Long specification.
 
+=item * B<summaries> => I<hash>
+
+Summary text for each option spec (key in `getopt_spec`).
+
 =item * B<words>* => I<array>
 
 Command line arguments, like @ARGV.
@@ -804,7 +822,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-G
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete-Getopt-Long>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Getopt-Long>.
 
 =head1 BUGS
 
@@ -834,7 +852,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
